@@ -6,5 +6,10 @@ from .http import (
     HTTPBearer,
     HTTPDigest,
 )
-from .oauth2 import OAuth2, OAuth2PasswordBearer, OAuth2PasswordRequestForm
+from .oauth2 import (
+    OAuth2,
+    OAuth2PasswordBearer,
+    OAuth2PasswordRequestForm,
+    SecurityScopes,
+)
 from .open_id_connect_url import OpenIdConnect
