@@ -3,6 +3,6 @@
 set -e
 set -x
 
-mypy fastapi --disallow-untyped-defs --follow-imports=skip
+mypy fastapi --disallow-untyped-defs
 black fastapi tests --check
 isort --multi-line=3 --trailing-comma --force-grid-wrap=0 --combine-as --line-width 88 --recursive --check-only --thirdparty fastapi fastapi tests
