@@ -74,10 +74,28 @@ openapi_schema = {
                         "description": "Successful Response",
                         "content": {"application/json": {"schema": {}}},
                     },
+                    "422": {
+                        "description": "Validation Error",
+                        "content": {
+                            "application/json": {
+                                "schema": {
+                                    "$ref": "#/components/schemas/HTTPValidationError"
+                                }
+                            }
+                        },
+                    },
                 },
                 "tags": ["items"],
                 "summary": "Read Items",
                 "operationId": "read_items_items__get",
+                "parameters": [
+                    {
+                        "required": True,
+                        "schema": {"title": "X-Token", "type": "string"},
+                        "name": "x-token",
+                        "in": "header",
+                    }
+                ],
             }
         },
         "/items/{item_id}": {
@@ -108,7 +126,13 @@ openapi_schema = {
                         "schema": {"title": "Item_Id", "type": "string"},
                         "name": "item_id",
                         "in": "path",
-                    }
+                    },
+                    {
+                        "required": True,
+                        "schema": {"title": "X-Token", "type": "string"},
+                        "name": "x-token",
+                        "in": "header",
+                    },
                 ],
             },
             "put": {
@@ -139,7 +163,13 @@ openapi_schema = {
                         "schema": {"title": "Item_Id", "type": "string"},
                         "name": "item_id",
                         "in": "path",
-                    }
+                    },
+                    {
+                        "required": True,
+                        "schema": {"title": "X-Token", "type": "string"},
+                        "name": "x-token",
+                        "in": "header",
+                    },
                 ],
             },
         },
@@ -177,29 +207,94 @@ openapi_schema = {
 
 
 @pytest.mark.parametrize(
-    "path,expected_status,expected_response",
+    "path,expected_status,expected_response,headers",
     [
-        ("/users", 200, [{"username": "Foo"}, {"username": "Bar"}]),
-        ("/users/foo", 200, {"username": "foo"}),
-        ("/users/me", 200, {"username": "fakecurrentuser"}),
-        ("/items", 200, [{"name": "Item Foo"}, {"name": "item Bar"}]),
-        ("/items/bar", 200, {"name": "Fake Specific Item", "item_id": "bar"}),
-        ("/openapi.json", 200, openapi_schema),
+        ("/users", 200, [{"username": "Foo"}, {"username": "Bar"}], {}),
+        ("/users/foo", 200, {"username": "foo"}, {}),
+        ("/users/me", 200, {"username": "fakecurrentuser"}, {}),
+        (
+            "/items",
+            200,
+            [{"name": "Item Foo"}, {"name": "item Bar"}],
+            {"X-Token": "fake-super-secret-token"},
+        ),
+        (
+            "/items/bar",
+            200,
+            {"name": "Fake Specific Item", "item_id": "bar"},
+            {"X-Token": "fake-super-secret-token"},
+        ),
+        ("/items", 400, {"detail": "X-Token header invalid"}, {"X-Token": "invalid"}),
+        (
+            "/items/bar",
+            400,
+            {"detail": "X-Token header invalid"},
+            {"X-Token": "invalid"},
+        ),
+        (
+            "/items",
+            422,
+            {
+                "detail": [
+                    {
+                        "loc": ["header", "x-token"],
+                        "msg": "field required",
+                        "type": "value_error.missing",
+                    }
+                ]
+            },
+            {},
+        ),
+        (
+            "/items/bar",
+            422,
+            {
+                "detail": [
+                    {
+                        "loc": ["header", "x-token"],
+                        "msg": "field required",
+                        "type": "value_error.missing",
+                    }
+                ]
+            },
+            {},
+        ),
+        ("/openapi.json", 200, openapi_schema, {}),
     ],
 )
-def test_get_path(path, expected_status, expected_response):
-    response = client.get(path)
+def test_get_path(path, expected_status, expected_response, headers):
+    response = client.get(path, headers=headers)
     assert response.status_code == expected_status
     assert response.json() == expected_response
 
 
-def test_put():
+def test_put_no_header():
     response = client.put("/items/foo")
+    assert response.status_code == 422
+    assert response.json() == {
+        "detail": [
+            {
+                "loc": ["header", "x-token"],
+                "msg": "field required",
+                "type": "value_error.missing",
+            }
+        ]
+    }
+
+
+def test_put_invalid_header():
+    response = client.put("/items/foo", headers={"X-Token": "invalid"})
+    assert response.status_code == 400
+    assert response.json() == {"detail": "X-Token header invalid"}
+
+
+def test_put():
+    response = client.put("/items/foo", headers={"X-Token": "fake-super-secret-token"})
     assert response.status_code == 200
     assert response.json() == {"item_id": "foo", "name": "The Fighters"}
 
 
 def test_put_forbidden():
-    response = client.put("/items/bar")
+    response = client.put("/items/bar", headers={"X-Token": "fake-super-secret-token"})
     assert response.status_code == 403
     assert response.json() == {"detail": "You can only update the item: foo"}
