@@ -16,7 +16,7 @@ openapi_schema = {
                         "content": {"application/json": {"schema": {}}},
                     }
                 },
-                "summary": "Read Items Get",
+                "summary": "Read Items",
                 "operationId": "read_items_items__get",
                 "security": [{"OAuth2PasswordBearer": []}],
             }
@@ -41,8 +41,9 @@ def test_openapi_schema():
 
 def test_no_token():
     response = client.get("/items")
-    assert response.status_code == 403
+    assert response.status_code == 401
     assert response.json() == {"detail": "Not authenticated"}
+    assert response.headers["WWW-Authenticate"] == "Bearer"
 
 
 def test_token():
@@ -53,5 +54,6 @@ def test_token():
 
 def test_incorrect_token():
     response = client.get("/items", headers={"Authorization": "Notexistent testtoken"})
-    assert response.status_code == 403
+    assert response.status_code == 401
     assert response.json() == {"detail": "Not authenticated"}
+    assert response.headers["WWW-Authenticate"] == "Bearer"
